@@ -33,7 +33,7 @@
 #include "codechal_decoder.h"
 #include "mos_os_virtualengine_scalability.h"
 
-#define CODEC_VTILE_MAX_NUM  4
+#define CODEC_VTILE_MAX_NUM  8
 
 // first tile column width
 
@@ -109,6 +109,7 @@ typedef struct _CODECHAL_DECODE_SCALABILITY_INIT_PARAMS
     uint8_t          u8NumTileColumns;               //!< Number of tile columns for this picture
     uint8_t          u8NumTileRows;                  //!< Number of tile rows for this picture
     MOS_GPU_CONTEXT  gpuCtxInUse;                    //!< gpu context in use
+    bool             usingSecureDecode;
 }CODECHAL_DECODE_SCALABILITY_INIT_PARAMS, *PCODECHAL_DECODE_SCALABILITY_INIT_PARAMS;
 
 typedef struct _CODECHAL_DECODE_SCALABILITY_STATE CODECHAL_DECODE_SCALABILITY_STATE, *PCODECHAL_DECODE_SCALABILITY_STATE;
@@ -126,6 +127,7 @@ struct _CODECHAL_DECODE_SCALABILITY_STATE
     bool                            bScalableDecodeMode;
 
     bool                            bFESeparateSubmission;
+    bool                            bFESeparateSubmissionVT;
     bool                            bShortFormatInUse;
     bool                            bUseSecdryCmdBuffer;
     bool                            bIsEvenSplit;
@@ -862,4 +864,17 @@ MOS_STATUS CodechalDecodeScalability_ChkGpuCtxReCreation(
     PCODECHAL_DECODE_SCALABILITY_STATE         pScalabilityState,
     PMOS_GPUCTX_CREATOPTIONS_ENHANCED          CurgpuCtxCreatOpts);
 
+//!
+//! \brief    Convert Decode Phase to Batch Buffer Submission Type
+//! \param    [in]  scalabilityState
+//!                Scalability decode state
+//! \param    [in] pCmdBuffer
+//!                Pointer to command buffer
+//! \return   void
+//!           void
+//!
+void CodecHalDecodeScalability_DecPhaseToSubmissionType(
+    PCODECHAL_DECODE_SCALABILITY_STATE pScalabilityState,
+    PMOS_COMMAND_BUFFER pCmdBuffer);
+
 #endif //__CODECHAL_DECODER_SCALABILITY_H__
