@@ -592,6 +592,7 @@ MOS_STATUS CodechalEncodeJpegState::ExecutePictureLevel()
     MOS_ZeroMemory(&surfaceParams, sizeof(surfaceParams));
     surfaceParams.Mode      = m_mode;
     surfaceParams.psSurface = &m_rawSurface; // original picture to be encoded
+    surfaceParams.ucSurfaceStateId = CODECHAL_MFX_SRC_SURFACE_ID;
 
     // set MFX_PIPE_BUF_ADDR_STATE
     MHW_VDBOX_PIPE_BUF_ADDR_PARAMS pipeBufAddrParams;
@@ -670,6 +671,9 @@ MOS_STATUS CodechalEncodeJpegState::ExecuteSliceLevel()
     CodecJpegQuantMatrix *tempJpegQuantMatrix = (CodecJpegQuantMatrix *)MOS_AllocAndZeroMemory(sizeof(CodecJpegQuantMatrix));
     CODECHAL_ENCODE_CHK_NULL_RETURN(tempJpegQuantMatrix);
 
+    static_assert(JPEG_MAX_NUM_QUANT_TABLE_INDEX <= JPEG_MAX_NUM_OF_QUANTMATRIX,
+        "access to CodecJpegQuantMatrix is controlled by numQuantTables");
+
     uint32_t numQuantTables = JPEG_MAX_NUM_QUANT_TABLE_INDEX;
     for (uint32_t scanCount = 0; scanCount < m_encodeParams.dwNumSlices; scanCount++)
     {
