@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2018, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -97,7 +97,7 @@ typedef struct _MHW_VDBOX_VDENC_CMD1_PARAMS
     uint32_t                                Mode;
     PCODEC_HEVC_ENCODE_PICTURE_PARAMS       pHevcEncPicParams;
     PCODEC_HEVC_ENCODE_SLICE_PARAMS         pHevcEncSlcParams;
-    PCODEC_VP9_ENCODE_PIC_PARAMS            pVp9EncPicParams = nullptr;;
+    PCODEC_VP9_ENCODE_PIC_PARAMS            pVp9EncPicParams = nullptr;
     uint8_t                                *pucVdencMvCosts;
     uint8_t                                *pucVdencRdMvCosts;
     uint8_t                                *pucVdencHmeMvCosts;
@@ -105,6 +105,9 @@ typedef struct _MHW_VDBOX_VDENC_CMD1_PARAMS
     void                                   *pInputParams;
     uint16_t                                usSADQPLambda = 0;
     uint16_t                                usRDQPLambda = 0;
+    uint8_t                                 frame_type;
+    uint8_t                                 qp;
+    bool                                    isLowDelay;
     bool                                    bHevcVisualQualityImprovement = false;  //!< VQI enable flag
 } MHW_VDBOX_VDENC_CMD1_PARAMS, *PMHW_VDBOX_VDENC_CMD1_PARAMS;
 
@@ -125,13 +128,14 @@ struct MHW_VDBOX_VDENC_CMD2_STATE
     bool                                    bPartialFrameUpdateEnable = false;
     uint32_t                                roundInterValue = 0;
     uint32_t                                roundIntraValue = 0;
+    uint8_t                                 bStreaminRoiMode = 0;
 
     // VP9
     PCODEC_VP9_ENCODE_PIC_PARAMS            pVp9EncPicParams = nullptr;
     bool                                    bSegmentationEnabled = false;
     PMHW_VDBOX_VP9_SEGMENT_STATE            pVp9SegmentState = nullptr;
     PCODEC_VP9_ENCODE_SEQUENCE_PARAMS       pVp9EncSeqParams = nullptr;
-    bool                                    bPrevFrameSegEnabled;
+    bool                                    bPrevFrameSegEnabled = false;
     bool                                    bDynamicScalingEnabled = false;
     bool                                    temporalMVpEnable = false;
 
@@ -335,6 +339,17 @@ public:
         uint32_t                        *commandsSize,
         uint32_t                        *patchListSize) = 0;
 
+    //!
+    //! \brief    get Vdenc slice commands data size
+    //!
+    //! \return   uint32_t
+    //!           Vdenc slice commands data size got
+    //!
+    virtual MOS_STATUS GetVdencPrimitiveCommandsDataSize(
+        uint32_t                        mode,
+        uint32_t                        *commandsSize,
+        uint32_t                        *patchListSize) = 0;
+
     //!
     //! \brief    Set cacheability settings
     //!
@@ -585,6 +600,8 @@ public:
         PMHW_BATCH_BUFFER                   batchBuffer,
         PMHW_VDBOX_VDENC_CMD2_STATE         params) = 0;
 
+    virtual PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS CreateMhwVdboxPipeModeSelectParams() = 0;
+    virtual void ReleaseMhwVdboxPipeModeSelectParams(PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS pipeModeSelectParams) = 0;
 };
 
 #endif
