@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2019, Intel Corporation
+* Copyright (c) 2009-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -211,7 +211,7 @@ private:
 #define MOS_COMMAND_BUFFER_RENDER_ENGINE   "CS"
 #define MOS_COMMAND_BUFFER_VIDEO_ENGINE    "VCS"
 #define MOS_COMMAND_BUFFER_VEBOX_ENGINE    "VECS"
-#define MOS_COMMAND_BUFFER_RTE_ENGINE      "RTE"
+#define MOS_COMMAND_BUFFER_TEE_ENGINE      "TEE"
 #define MOS_COMMAND_BUFFER_PLATFORM_LEN    4
 #endif // MOS_COMMAND_BUFFER_DUMP_SUPPORTED
 
@@ -430,11 +430,12 @@ typedef struct _MOS_ALLOC_GFXRES_PARAMS
     MOS_TILE_TYPE       TileType;                                               //!< [in] Defines the layout of a physical page. Optimal choice depends on usage model.
     MOS_FORMAT          Format;                                                 //!< [in] Pixel format
     void                *pSystemMemory;                                         //!< [in] Optional parameter. If non null, TileType must be set to linear.
-    const char          *pBufName;                                              //!< [in] Optional parameter only used in Linux. A string indicates the buffer name and is used for debugging. nullptr is OK.
+    const char          *pBufName;                                              //!< [in] Optional parameter. A string indicates the buffer name and is used for debugging. nullptr is OK.
     int32_t             bIsCompressible;                                        //!< [in] Resource is compressible or not.
     MOS_RESOURCE_MMC_MODE   CompressionMode;                                    //!< [in] Compression mode.
     int32_t             bIsPersistent;                                          //!< [in] Optional parameter. Used to indicate that resource can not be evicted
     int32_t             bBypassMODImpl;
+    int32_t             dwMemType;                                              //!< [in] Optional paramerter. Prefer memory type
 } MOS_ALLOC_GFXRES_PARAMS, *PMOS_ALLOC_GFXRES_PARAMS;
 
 //!
@@ -553,30 +554,48 @@ struct MosStreamState
     GPU_CONTEXT_HANDLE currentGpuContextHandle = MOS_GPU_CONTEXT_INVALID_HANDLE;
     MOS_COMPONENT      component;
 
-    MosVeInterface *virtualEngineInterface = nullptr;
-    MosCpInterface *osCpInterface = nullptr;
+    bool supportVirtualEngine = false; //!< Flag to indicate using virtual engine interface
+    MosVeInterface *virtualEngineInterface = nullptr; //!< Interface to virtual engine state
+    bool useHwSemaForResSyncInVe = false; //!< Flag to indicate if UMD need to send HW sema cmd under this OS when there is a resource sync need with Virtual Engine interface
+    bool veEnable = false;                //!< Flag to indicate virtual engine enabled (Can enable VE without using virtual engine interface)
+    bool phasedSubmission = false;        //!< Flag to indicate if secondary command buffers are submitted together or separately due to different OS
+    bool frameSplit = true;               //!< Flag to indicate if frame split is enabled (only active when phasedSubmission is true)
+    bool hcpDecScalabilityMode = false;   //!< Hcp scalability mode
+    bool veboxScalabilityMode = false;    //!< Vebox scalability mode
 
-    bool mediaReset    = false;
-    uint32_t GpuResetCount = 0;
+    bool ctxBasedScheduling = false;  //!< Indicate if context based scheduling is enabled in this stream
+    bool multiNodeScaling = false;    //!< Flag to indicate if multi-node scaling is enabled for virtual engine (only active when ctxBasedScheduling is true)
+
+    bool softReset = false;  //!< trigger soft reset
+
+    MosCpInterface *osCpInterface = nullptr; //!< CP interface
+
+    bool mediaReset    = false;  //!< Flag to indicate media reset is enabled
 
     bool simIsActive = false;  //!< Flag to indicate if Simulation is enabled
     MOS_NULL_RENDERING_FLAGS nullHwAccelerationEnable; //!< To indicate which components to enable Null HW support
 
+    bool usesPatchList = false;               //!< Uses patch list instead of graphic address directly
+    bool usesGfxAddress = false;              //!< Uses graphic address directly instead of patch list
+    bool enableKmdMediaFrameTracking = false; //!< Enable KMD Media frame tracking
+    bool usesCmdBufHeaderInResize = false;    //!< Use cmd buffer header in resize
+    bool usesCmdBufHeader = false;            //!< Use cmd buffer header
+
 #if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
     // Command buffer dump
     bool  dumpCommandBuffer = false;                      //!< Flag to indicate if Dump command buffer is enabled
     bool  dumpCommandBufferToFile = false;                //!< Indicates that the command buffer should be dumped to a file
     bool  dumpCommandBufferAsMessages = false;            //!< Indicates that the command buffer should be dumped via MOS normal messages
+    char  sDirName[MOS_MAX_HLT_FILENAME_LEN] = {0};       //!< Dump Directory name - maximum 260 bytes length
 #endif // MOS_COMMAND_BUFFER_DUMP_SUPPORTED
 
 #if _DEBUG || _RELEASE_INTERNAL
-    bool  enableDbgOvrdInVirtualEngine = false;
+    bool  enableDbgOvrdInVirtualEngine = false; //!< enable debug override in virtual engine
 
-    int32_t eForceVdbox = 0;   //!< Force select Vdbox
+    int32_t eForceVdbox = 0;  //!< Force select Vdbox
     int32_t eForceVebox = 0;  //!< Force select Vebox
 #endif // _DEBUG || _RELEASE_INTERNAL
 
-    bool  ctxBasedScheduling = false;  //!< Indicate if context based scheduling is enabled in this stream
     OS_PER_STREAM_PARAMETERS  perStreamParameters = nullptr; //!< Parameters of OS specific per stream
 };
 
@@ -593,6 +612,7 @@ typedef void *              OsSpecificRes;       //!< stand for different os spe
 typedef void *              OS_HANDLE;           //!< stand for different os handles
 typedef MOS_SURFACE         MosResourceInfo;
 typedef void *              DDI_DEVICE_CONTEXT;  //!< stand for different os specific device context
+typedef void *              MOS_INTERFACE_HANDLE;
 
 class GpuContextMgr;
 //!
@@ -622,7 +642,7 @@ typedef struct _MOS_INTERFACE
     int32_t                         bUsesCmdBufHeaderInResize;
     int32_t                         bEnableKmdMediaFrameTracking;
     int32_t                         bNoParsingAssistanceInKmd;
-    bool                            bPitchAndUVPatchingNeeded;
+    bool                            bPitchAndUVPatchingNeeded = false;
     uint32_t                        dwCommandBufferReservedSpace;
     uint32_t                        dwNumNalUnitBytesIncluded;
 
@@ -699,6 +719,8 @@ typedef struct _MOS_INTERFACE
     int32_t                         bTriggerVPHang;                               //!< trigger GPU HANG in VP
 #endif // (_DEBUG || _RELEASE_INTERNAL)
 
+    bool                            apoMosEnabled;                                //!< apo mos or not
+
     MEMORY_OBJECT_CONTROL_STATE (* pfnCachePolicyGetMemoryObject) (
         MOS_HW_RESOURCE_DEF         Usage,
         GMM_CLIENT_CONTEXT          *pGmmClientContext);
@@ -965,6 +987,16 @@ typedef struct _MOS_INTERFACE
         PMOS_RESOURCE         pOutputOsResource,
         bool                  bOutputCompressed);
 
+    MOS_STATUS(*pfnMediaCopyResource2D) (
+        PMOS_INTERFACE        pOsInterface,
+        PMOS_RESOURCE         pInputOsResource,
+        PMOS_RESOURCE         pOutputOsResource,
+        uint32_t              copyWidth,
+        uint32_t              copyHeight,
+        uint32_t              copyInputOffset,
+        uint32_t              copyOutputOffset,
+        bool                  bOutputCompressed);
+
     MOS_STATUS (* pfnFillResource) (
         PMOS_INTERFACE              pOsInterface,
         PMOS_RESOURCE               pResource,
@@ -1177,6 +1209,12 @@ typedef struct _MOS_INTERFACE
     MOS_STATUS(*pfnSkipResourceSync)(
         PMOS_RESOURCE               pOsResource);
 
+    MOS_STATUS(*pfnSkipResourceSyncDynamic)(
+        PMOS_RESOURCE               pOsResource);
+
+    MOS_STATUS(*pfnEnableResourceSyncDynamic)(
+        PMOS_RESOURCE               pOsResource);
+
     bool(*pfnIsValidStreamID)(
         PMOS_RESOURCE               pOsResource);
 
@@ -1282,6 +1320,8 @@ typedef struct _MOS_INTERFACE
     int32_t                         bVeboxScalabilityMode;                        //!< Enable scalability vebox
     int32_t                         bSoftReset;                                   //!< trigger soft reset
 #endif // (_DEBUG || _RELEASE_INTERNAL)
+    bool streamStateIniter = false;
+
     //!< os interface extension
     void                            *pOsExt;
 } MOS_INTERFACE;
@@ -1304,6 +1344,15 @@ MOS_STATUS Mos_InitInterface(
     PMOS_CONTEXT        pOsDriverContext,
     MOS_COMPONENT       component);
 
+//! \brief    Destroy the mos interface
+//! \details  MOS Interface release
+//! \param    PMOS_INTERFACE pOsInterface
+//!           [in/out] Pointer to OS Interface
+//! \return   MOS_STATUS
+//!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+//!
+MOS_STATUS Mos_DestroyInterface(PMOS_INTERFACE pOsInterface);
+
 //! \brief    Unified OS add command to command buffer
 //! \details  Offset returned is dword aligned but size requested can be byte aligned
 //! \param    PMOS_COMMAND_BUFFER pCmdBuffer
