@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2019, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -705,36 +705,3 @@ MOS_STATUS DecodeHistogramDeviceG11Icllp::Initialize(
 
     return MOS_STATUS_SUCCESS;
 }
-
-static bool ehlRegisteredVphal =
-      MediaInterfacesFactory<VphalDevice>::
-      RegisterHal<VphalInterfacesG11Icllp>((uint32_t)IGFX_ELKHARTLAKE);
-
-static bool ehlRegisteredMhw =
-    MediaInterfacesFactory<MhwInterfaces>::
-    RegisterHal<MhwInterfacesG11Icllp>((uint32_t)IGFX_ELKHARTLAKE);
-
-static bool ehlRegisteredNv12ToP010 =
-    MediaInterfacesFactory<Nv12ToP010Device>::
-    RegisterHal<Nv12ToP010DeviceG11Icllp>((uint32_t)IGFX_ELKHARTLAKE);
-
-static bool ehlhpRegisteredCodecHal =
-    MediaInterfacesFactory<CodechalDevice>::
-    RegisterHal<CodechalInterfacesG11Icllp>((uint32_t)IGFX_ELKHARTLAKE);
-
-static bool ehlRegisteredCMHal =
-    MediaInterfacesFactory<CMHalDevice>::
-    RegisterHal<CMHalInterfacesG11Icllp>((uint32_t)IGFX_ELKHARTLAKE);
-
-static bool ehlRegisteredMosUtil =
-    MediaInterfacesFactory<MosUtilDevice>::
-    RegisterHal<MosUtilDeviceG11Icllp>((uint32_t)IGFX_ELKHARTLAKE);
-
-static bool ehlRegisteredRenderHal =
-    MediaInterfacesFactory<RenderHalDevice>::
-    RegisterHal<RenderHalInterfacesG11Icllp>((uint32_t)IGFX_ELKHARTLAKE);
-
-static bool ehlRegisteredDecodeHistogram =
-    MediaInterfacesFactory<DecodeHistogramDevice>::
-    RegisterHal<DecodeHistogramDeviceG11Icllp>((uint32_t)IGFX_ELKHARTLAKE);
-
