@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2019, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
 */
 //!
 //! \file       renderhal_g12.cpp
-//! \brief      implementation of Gen11 hardware functions
+//! \brief      implementation of Gen12 hardware functions
 //! \details    Render functions
 //!
 
@@ -142,7 +142,8 @@ MOS_STATUS XRenderHal_Interface_g12::SetupSurfaceState (
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pStateHeap);
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pHwSizes);
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwStateHeap);
-    MHW_RENDERHAL_ASSERT(pRenderHalSurface->Rotation >= 0 && pRenderHalSurface->Rotation < 8);
+    MHW_RENDERHAL_ASSERT(pRenderHalSurface->Rotation >= 0 &&
+                         pRenderHalSurface->Rotation <= MHW_ROTATE_90_MIRROR_HORIZONTAL);
     //-----------------------------------------
 
     dwSurfaceSize = pRenderHal->pHwSizes->dwSizeSurfaceState;
@@ -163,6 +164,7 @@ MOS_STATUS XRenderHal_Interface_g12::SetupSurfaceState (
         pSurfaceEntry = ppSurfaceEntries[i];
 
         pSurface = pSurfaceEntry->pSurface;
+        MHW_RENDERHAL_CHK_NULL(pSurface);
 
         // Set the Surface State Offset from base of SSH
         pSurfaceEntry->dwSurfStateOffset = pRenderHal->pStateHeap->iSurfaceStateOffset +                // Offset to Base Of Current Surface State Area
@@ -181,6 +183,21 @@ MOS_STATUS XRenderHal_Interface_g12::SetupSurfaceState (
         SurfStateParams.dwCacheabilityControl = pRenderHal->pfnGetSurfaceMemoryObjectControl(pRenderHal, pParams);
         SurfStateParams.RotationMode          = g_cLookup_RotationMode_g12[pRenderHalSurface->Rotation];
 
+    #if !EMUL
+        if (pRenderHal->pOsInterface !=nullptr)
+        {
+            GMM_RESOURCE_FLAG                   gmmFlags = {0};
+            gmmFlags = pSurface->OsResource.pGmmResInfo->GetResFlags();
+            if (gmmFlags.Gpu.CameraCapture)
+            {
+                SurfStateParams.dwCacheabilityControl = pRenderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
+                    MOS_MHW_GMM_RESOURCE_USAGE_CAMERA_CAPTURE,
+                    pRenderHal->pOsInterface->pfnGetGmmClientContext(pRenderHal->pOsInterface)).DwordValue;
+                MHW_RENDERHAL_NORMALMESSAGE(" disable  CameraCapture  caches on render path ");
+            }
+        }
+    #endif
+
         if (IsFormatMMCSupported(pSurface->Format) &&
             m_renderHalMMCEnabled)
         {
@@ -837,19 +854,17 @@ MOS_STATUS XRenderHal_Interface_g12::IsRenderHalMMCEnabled(
 
     // Read user feature key to set MMC for Fast Composition surfaces
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
-    UserFeatureData.i32DataFlag = MOS_USER_FEATURE_VALUE_DATA_FLAG_CUSTOM_DEFAULT_VALUE_TYPE;
-#ifdef LINUX
-    UserFeatureData.bData       = false; // disable MMC on Linux
-#else
-    UserFeatureData.bData       = true; // init as default value to enable MMCD on Gen12LP
-#endif
 
-#if (_DEBUG || _RELEASE_INTERNAL)
+    UserFeatureData.i32DataFlag = MOS_USER_FEATURE_VALUE_DATA_FLAG_CUSTOM_DEFAULT_VALUE_TYPE;
+#if(LINUX)
+    UserFeatureData.bData = !MEDIA_IS_WA(pRenderHal->pWaTable, WaDisableVPMmc) || !MEDIA_IS_WA(pRenderHal->pWaTable, WaDisableCodecMmc); // Enable MMC on Linux based on platforms settings
+#else
+    UserFeatureData.bData = true; // init as default value to enable MMCD on Gen12LP
+#endif
     MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_ENABLE_RENDER_ENGINE_MMC_ID,
         &UserFeatureData));
-#endif
 
     m_renderHalMMCEnabled = UserFeatureData.bData && MEDIA_IS_SKU(pRenderHal->pSkuTable, FtrE2ECompression);
     pRenderHal->isMMCEnabled = m_renderHalMMCEnabled;
@@ -1019,6 +1034,7 @@ bool XRenderHal_Interface_g12::IsFormatMMCSupported(MOS_FORMAT format)
         (format != Format_400P)             &&
         (format != Format_420O)             &&
         (format != Format_R8UN)             &&
+        (format != Format_A8)               &&
         (format != Format_R8G8UN))
     {
         MHW_RENDERHAL_NORMALMESSAGE("Unsupported Format '0x%08x' for Render MMC.", format);
