@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2018, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -283,9 +283,9 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::GetFFDISurfParams(
     // output surface's SampleType should be same to input's. Bob is being
     // done in Composition part
     if (pRenderData->bIECP &&
-        (m_currentSurface->pDeinterlaceParams                         &&
+        ((m_currentSurface->pDeinterlaceParams                         &&
          m_currentSurface->pDeinterlaceParams->DIMode == DI_MODE_BOB) ||
-         m_currentSurface->bInterlacedScaling)
+         m_currentSurface->bInterlacedScaling))
     {
         SampleType = m_currentSurface->SampleType;
     }
@@ -393,8 +393,8 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
     int32_t                i;
     bool                   bAllocated;
     bool                   bDIEnable;
-    bool                   bSurfCompressed;
-    bool                   bFFDNSurfCompressed;
+    bool                   bSurfCompressible;
+    bool                   bFFDNSurfCompressible;
     MOS_RESOURCE_MMC_MODE  SurfCompressionMode;
     MOS_RESOURCE_MMC_MODE  FFDNSurfCompressionMode;
     MHW_VEBOX_SURFACE_PARAMS      MhwVeboxSurfaceParam;
@@ -403,8 +403,8 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
     PVPHAL_VEBOX_RENDER_DATA      pRenderData = GetLastExecRenderData();
 
     bAllocated              = false;
-    bSurfCompressed         = false;
-    bFFDNSurfCompressed     = false;
+    bSurfCompressible       = false;
+    bFFDNSurfCompressible   = false;
     SurfCompressionMode     = MOS_MMC_DISABLED;
     FFDNSurfCompressionMode = MOS_MMC_DISABLED;
     pOsInterface            = pVeboxState->m_pOsInterface;
@@ -419,7 +419,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
     // or none of them compressed at all.This is HW limitation.
     if (IsDNOnly())
     {
-        bSurfCompressed     = pVeboxState->m_currentSurface->bCompressible;
+        bSurfCompressible   = pVeboxState->m_currentSurface->bCompressible;
         SurfCompressionMode = pVeboxState->m_currentSurface->bIsCompressed ? MOS_MMC_HORIZONTAL : MOS_MMC_DISABLED;
     }
     // Only Tiled Y surfaces support MMC
@@ -427,7 +427,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
              (TileType == MOS_TILE_Y) &&
              pVeboxState->IsFormatMMCSupported(format))
     {
-        bSurfCompressed     = true;
+        bSurfCompressible   = true;
         SurfCompressionMode = MOS_MMC_HORIZONTAL;
     }
 
@@ -450,7 +450,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
                     TileType,
                     pVeboxState->m_currentSurface->dwWidth,
                     pVeboxState->m_currentSurface->dwHeight,
-                    bSurfCompressed,
+                    bSurfCompressible,
                     SurfCompressionMode,
                     &bAllocated));
 
@@ -471,11 +471,24 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
             if (bAllocated)
             {
                 // Report Compress Status
-                m_reporting->FFDICompressible = bSurfCompressed;
+                m_reporting->FFDICompressible = bSurfCompressible;
                 m_reporting->FFDICompressMode = (uint8_t)(SurfCompressionMode);
             }
         }
     }
+    else
+    {
+        // Free FFDI surfaces
+        for (i = 0; i < pVeboxState->iNumFFDISurfaces; i++)
+        {
+            if (pVeboxState->FFDISurfaces[i])
+            {
+                pOsInterface->pfnFreeResource(
+                    pOsInterface,
+                    &pVeboxState->FFDISurfaces[i]->OsResource);
+            }
+        }
+    }
 
     // When DI switch to DNDI, the first FFDN surface pitch doesn't match with
     // the input surface pitch and cause the flicker issue
@@ -483,14 +496,14 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
     // when the second clip playback starting without media pipeline recreation,
     // the internal FFDNSurfaces are compressed, but VP input surface is uncompressed.
     if ((pVeboxState->bDIEnabled && !pVeboxState->bDNEnabled && pRenderData->bDenoise) ||
-        ((pVeboxState->m_currentSurface->bIsCompressed == false) && ((bSurfCompressed == true) || (pVeboxState->FFDNSurfaces[0]->bIsCompressed == true))))
+        ((pVeboxState->m_currentSurface->bIsCompressed == false) && ((bSurfCompressible == true) || (pVeboxState->FFDNSurfaces[0]->bIsCompressed == true))))
     {
-        bFFDNSurfCompressed     = pVeboxState->m_currentSurface->bCompressible;
+        bFFDNSurfCompressible   = pVeboxState->m_currentSurface->bCompressible;
         FFDNSurfCompressionMode = pVeboxState->m_currentSurface->bIsCompressed ? MOS_MMC_HORIZONTAL : MOS_MMC_DISABLED;
     }
     else
     {
-        bFFDNSurfCompressed     = bSurfCompressed;
+        bFFDNSurfCompressible   = bSurfCompressible;
         FFDNSurfCompressionMode = SurfCompressionMode;
     }
 
@@ -508,7 +521,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
                     pVeboxState->m_currentSurface->TileType,
                     pVeboxState->m_currentSurface->dwWidth,
                     pVeboxState->m_currentSurface->dwHeight,
-                    bFFDNSurfCompressed,
+                    bFFDNSurfCompressible,
                     FFDNSurfCompressionMode,
                     &bAllocated));
 
@@ -550,11 +563,24 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
             if (bAllocated)
             {
                 // Report Compress Status
-                m_reporting->FFDNCompressible = bFFDNSurfCompressed;
+                m_reporting->FFDNCompressible = bFFDNSurfCompressible;
                 m_reporting->FFDNCompressMode = (uint8_t)(FFDNSurfCompressionMode);
             }
         }
     }
+    else
+    {
+        // Free FFDN surfaces
+        for (i = 0; i < VPHAL_NUM_FFDN_SURFACES; i++)
+        {
+            if (pVeboxState->FFDNSurfaces[i])
+            {
+                pOsInterface->pfnFreeResource(
+                    pOsInterface,
+                    &pVeboxState->FFDNSurfaces[i]->OsResource);
+            }
+        }
+    }
 
     // Adjust the rcMaxSrc of pRenderTarget when Vebox output is enabled
     if (IS_VPHAL_OUTPUT_PIPE_VEBOX(pRenderData))
@@ -567,12 +593,12 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
     {
         if (pVeboxState->bEnableMMC)
         {
-            bSurfCompressed     = true;
+            bSurfCompressible   = true;
             SurfCompressionMode = MOS_MMC_HORIZONTAL;
         }
         else
         {
-            bSurfCompressed     = false;
+            bSurfCompressible   = false;
             SurfCompressionMode = MOS_MMC_DISABLED;
         }
 
@@ -587,7 +613,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
                 MOS_TILE_Y,
                 pVeboxState->m_currentSurface->dwWidth,
                 pVeboxState->m_currentSurface->dwHeight,
-                bSurfCompressed,
+                bSurfCompressible,
                 SurfCompressionMode,
                 &bAllocated));
 
@@ -596,11 +622,50 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
                 VPHAL_RENDER_CHK_STATUS(VeboxInitSTMMHistory(i));
 
                 // Report Compress Status
-                m_reporting->STMMCompressible = bSurfCompressed;
+                m_reporting->STMMCompressible = bSurfCompressible;
                 m_reporting->STMMCompressMode = (uint8_t)(SurfCompressionMode);
             }
         }
     }
+    else
+    {
+        // Free DI history buffers (STMM = Spatial-temporal motion measure)
+        for (i = 0; i < VPHAL_NUM_STMM_SURFACES; i++)
+        {
+            pOsInterface->pfnFreeResource(
+                pOsInterface,
+                &pVeboxState->STMMSurfaces[i].OsResource);
+        }
+    }
+
+    // Allocate BT2020 CSC temp surface----------------------------------------------
+    if (pRenderData->b2PassesCSC)
+    {
+        VPHAL_RENDER_CHK_STATUS(VpHal_ReAllocateSurface(
+            pOsInterface,
+            &pVeboxState->m_BT2020CSCTempSurface,
+            "VeboxBT2020CSCTempSurface_g9",
+            Format_A8B8G8R8,
+            MOS_GFXRES_2D,
+            MOS_TILE_Y,
+            pVeboxState->m_currentSurface->dwWidth,
+            pVeboxState->m_currentSurface->dwHeight,
+            false,
+            MOS_MMC_DISABLED,
+            &bAllocated));
+
+        // Copy rect sizes so that if input surface state needs to adjust,
+        // output surface can be adjustted also.
+        pVeboxState->m_BT2020CSCTempSurface.rcSrc = pVeboxState->m_currentSurface->rcSrc;
+        pVeboxState->m_BT2020CSCTempSurface.rcDst = pVeboxState->m_currentSurface->rcDst;
+        // Copy max src rect
+        pVeboxState->m_BT2020CSCTempSurface.rcMaxSrc = pVeboxState->m_currentSurface->rcMaxSrc;
+
+        // Copy Rotation, it's used in setting SFC state
+        pVeboxState->m_BT2020CSCTempSurface.Rotation   = pVeboxState->m_currentSurface->Rotation;
+        pVeboxState->m_BT2020CSCTempSurface.SampleType = pVeboxState->m_currentSurface->SampleType;
+        pVeboxState->m_BT2020CSCTempSurface.ColorSpace = CSpace_sRGB;
+    }
 
     // Allocate Statistics State Surface----------------------------------------
     // Width to be a aligned on 64 bytes and height is 1/4 the height
@@ -754,6 +819,11 @@ void VPHAL_VEBOX_STATE_G9_BASE::FreeResources()
         pOsInterface,
         &pVeboxState->VeboxStatisticsSurface.OsResource);
 
+    // Free BT2020 CSC temp surface for VEBOX used by BT2020 CSC
+    pOsInterface->pfnFreeResource(
+        pOsInterface,
+        &pVeboxState->m_BT2020CSCTempSurface.OsResource);
+
 #if VEBOX_AUTO_DENOISE_SUPPORTED
     // Free Spatial Attributes Configuration Surface for DN kernel
     pOsInterface->pfnFreeResource(
@@ -1548,6 +1618,17 @@ VPHAL_OUTPUT_PIPE_MODE VPHAL_VEBOX_STATE_G9_BASE::GetOutputPipe(
         goto finish;
     }
 
+    //Let Kernel to cover the DI cases VEBOX cannot handle.
+    if (pSrcSurface->pDeinterlaceParams &&
+        pSrcSurface->pDeinterlaceParams->DIMode == DI_MODE_BOB &&
+        ((IS_VEBOX_SURFACE_HEIGHT_UNALIGNED(pSrcSurface, 4) &&
+          pSrcSurface->Format == Format_NV12) ||
+         !this->IsDiFormatSupported(pSrcSurface)))
+    {
+        OutputPipe = VPHAL_OUTPUT_PIPE_MODE_COMP;
+        goto finish;
+    }
+
     bOutputPipeVeboxFeasible = IS_OUTPUT_PIPE_VEBOX_FEASIBLE(pVeboxState, pcRenderParams, pSrcSurface);
     if (bOutputPipeVeboxFeasible)
     {
@@ -1555,6 +1636,12 @@ VPHAL_OUTPUT_PIPE_MODE VPHAL_VEBOX_STATE_G9_BASE::GetOutputPipe(
         goto finish;
     }
 
+    if (VeboxIs2PassesCSCNeeded(pSrcSurface, pcRenderParams->pTarget[0]))
+    {
+        OutputPipe = VPHAL_OUTPUT_PIPE_MODE_COMP;
+        goto finish;
+    }
+
     pTarget    = pcRenderParams->pTarget[0];
     // Check if SFC can be the output pipe
     if (m_sfcPipeState)
@@ -1632,6 +1719,7 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsNeeded(
     pSrcSurface   = pRenderPassData->pSrcSurface;
 
     VPHAL_RENDER_CHK_NULL(pSrcSurface);
+    VPHAL_RENDER_CHK_NULL(pRenderTarget);
 
     // Check whether VEBOX is available
     // VTd doesn't support VEBOX
@@ -1641,8 +1729,8 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsNeeded(
         goto finish;
     }
 
-    // check if UserPtr enabling.
-    if (pcRenderParams->bUserPrt_16Align[0])
+    // check if 16aligned UserPtr enabling.
+    if (pSrcSurface->b16UsrPtr || pRenderTarget->b16UsrPtr)
     {
         pRenderPassData->bCompNeeded = true;
         goto finish;
@@ -1682,7 +1770,8 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsNeeded(
     SET_VPHAL_COMPONENT(pRenderData, pcRenderParams->Component);
 
     // Check if Vebox can be used to process the surface
-    if (pVeboxState->IsFormatSupported(pSrcSurface))
+    // if Hdr enabled on Gen9, do not use VE feature to avoid VPOutputPipe report fail.
+    if (!pRenderPassData->bHdrNeeded && pVeboxState->IsFormatSupported(pSrcSurface))
     {
         // Save Alpha passed by App to be used in Vebox
         if (IS_VPHAL_OUTPUT_PIPE_VEBOX(pRenderData))
@@ -1695,6 +1784,11 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsNeeded(
             pSrcSurface,
             pRenderTarget);
 
+        if (pRenderData->b2PassesCSC)
+        {
+            pRenderData->bVeboxBypass = false;
+        }
+
         // Vebox is needed if Vebox isn't bypassed
         bVeboxNeeded = !pRenderData->bVeboxBypass;
     }
@@ -1708,6 +1802,15 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsNeeded(
         pRenderPassData->bCompNeeded = true;
     }
 
+    if (pRenderPassData->bHdrNeeded && IS_VPHAL_OUTPUT_PIPE_SFC(pRenderData))
+    {
+        // The comp bypass check is skipped for SFC feasibiliy to allow HDR support,
+        // if still HdrSfc path is not enabled, need to switch back to composition (HDR render path)
+        // otherwise, traditional SFC path will direct output to render target and not compatible with HDR render path.
+        pRenderData->OutputPipe         = VPHAL_OUTPUT_PIPE_MODE_COMP;
+        pRenderPassData->bCompNeeded    = true;
+    }
+
     // Check if we want to enable SFC processing
     if (IS_VPHAL_OUTPUT_PIPE_SFC(pRenderData))
     {
@@ -2074,9 +2177,13 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsFormatSupported(
     // Vebox only support P016 format, P010 format can be supported by faking it as P016
     if (pSrcSurface->Format != Format_NV12 &&
         pSrcSurface->Format != Format_AYUV &&
-        pSrcSurface->Format != Format_Y416 &&
         pSrcSurface->Format != Format_P010 &&
         pSrcSurface->Format != Format_P016 &&
+        pSrcSurface->Format != Format_P210 &&
+        pSrcSurface->Format != Format_P216 &&
+        pSrcSurface->Format != Format_Y8   &&
+        pSrcSurface->Format != Format_Y16U &&
+        pSrcSurface->Format != Format_Y16S &&
         !IS_PA_FORMAT(pSrcSurface->Format))
     {
         VPHAL_RENDER_NORMALMESSAGE("Unsupported Source Format '0x%08x' for VEBOX.", pSrcSurface->Format);
@@ -2108,8 +2215,16 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsRTFormatSupported(
     bRet = false;
 
     // Check if RT Format is supported by Vebox
-    if (IS_PA_FORMAT(pRTSurface->Format) ||
-        pRTSurface->Format == Format_NV12)
+    if (IS_PA_FORMAT(pRTSurface->Format)  ||
+        pRTSurface->Format == Format_NV12 ||
+        pRTSurface->Format == Format_AYUV ||
+        pRTSurface->Format == Format_P010 ||
+        pRTSurface->Format == Format_P016 ||
+        pRTSurface->Format == Format_P210 ||
+        pRTSurface->Format == Format_P216 ||
+        pRTSurface->Format == Format_Y8   ||
+        pRTSurface->Format == Format_Y16U ||
+        pRTSurface->Format == Format_Y16S)
     {
         // Supported Vebox Render Target format. Vebox Pipe Output can be selected.
         bRet = true;
