@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2017, Intel Corporation
+* Copyright (c) 2009-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -89,6 +89,36 @@ static __inline PDDI_DECODE_CONTEXT DdiDecode_GetDecContextFromPVOID (void *decC
     return (PDDI_DECODE_CONTEXT)decCtx;
 }
 
+//!
+//! \brief  Status report
+//!
+//! \param  [in] decoder
+//!     CodechalDecode decoder
+//!
+//! \return VAStatus
+//!     VA_STATUS_SUCCESS if success, else fail reason
+//!
+VAStatus DdiDecode_StatusReport(
+    PDDI_MEDIA_CONTEXT mediaCtx,
+    CodechalDecode *decoder,
+    DDI_MEDIA_SURFACE *surface);
+
+#if _APOGEIOS_SUPPORTED
+//!
+//! \brief  Status report
+//!
+//! \param  [in] decoder
+//!     DecodePipelineAdapter decoder
+//!
+//! \return VAStatus
+//!     VA_STATUS_SUCCESS if success, else fail reason
+//!
+VAStatus DdiDecode_StatusReport(
+    PDDI_MEDIA_CONTEXT mediaCtx,
+    DecodePipelineAdapter *decoder,
+    DDI_MEDIA_SURFACE *surface);
+#endif
+
 //!
 //! \brief  Create buffer
 //!
